package com.fs.baidu.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.baidu.domain.BdAccount;
import com.fs.common.core.domain.R;
import com.fs.qw.param.ConversionStatisticsParam;

/**
 * 百度账号Service接口
 * 
 * @author fs
 * @date 2025-01-20
 */
public interface IBdAccountService extends IService<BdAccount>{
    /**
     * 查询百度账号
     * 
     * @param id 百度账号主键
     * @return 百度账号
     */
    BdAccount selectBdAccountById(Long id);

    /**
     * 查询百度账号列表
     * 
     * @param bdAccount 百度账号
     * @return 百度账号集合
     */
    List<BdAccount> selectBdAccountList(BdAccount bdAccount);

    /**
     * 新增百度账号
     * 
     * @param bdAccount 百度账号
     * @return 结果
     */
    int insertBdAccount(BdAccount bdAccount);

    /**
     * 修改百度账号
     * 
     * @param bdAccount 百度账号
     * @return 结果
     */
    int updateBdAccount(BdAccount bdAccount);

    /**
     * 批量删除百度账号
     * 
     * @param ids 需要删除的百度账号主键集合
     * @return 结果
     */
    int deleteBdAccountByIds(Long[] ids);

    /**
     * 删除百度账号信息
     * 
     * @param id 百度账号主键
     * @return 结果
     */
    int deleteBdAccountById(Long id);

    List<BdAccount> listByApiId(Long apiId);

    R conversionStatistics(ConversionStatisticsParam param);
}
